# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/requests/util/errors/error.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.util.errors import message_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+fintekkers/requests/util/errors/error.proto\x12\x1f\x66intekkers.requests.util.errors\x1a-fintekkers/requests/util/errors/message.proto\"\x80\x01\n\nErrorProto\x12\x38\n\x04\x63ode\x18\x01 \x01(\x0e\x32*.fintekkers.requests.util.errors.ErrorCode\x12\x38\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32(.fintekkers.requests.util.errors.Message\"\x82\x01\n\x0cWarningProto\x12\x38\n\x04\x63ode\x18\x01 \x01(\x0e\x32*.fintekkers.requests.util.errors.ErrorCode\x12\x38\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32(.fintekkers.requests.util.errors.Message*+\n\tErrorCode\x12\x11\n\rUNKNOWN_ERROR\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.util.errors.error_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ERRORCODE._serialized_start=391
  _ERRORCODE._serialized_end=434
  _ERRORPROTO._serialized_start=128
  _ERRORPROTO._serialized_end=256
  _WARNINGPROTO._serialized_start=259
  _WARNINGPROTO._serialized_end=389
# @@protoc_insertion_point(module_scope)
