from fintekkers.requests.valuation import valuation_request_pb2 as _valuation_request_pb2
from fintekkers.requests.valuation import valuation_response_pb2 as _valuation_response_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import service as _service
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Valuation(_service.service): ...

class Valuation_Stub(Valuation): ...
