from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
FIXED: CouponTypeProto
FLOAT: CouponTypeProto
UNKNOWN_COUPON_TYPE: CouponTypeProto
ZERO: CouponTypeProto

class CouponTypeProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
