from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

CREATE: RequestOperationTypeProto
DESCRIPTOR: _descriptor.FileDescriptor
GET: RequestOperationTypeProto
SEARCH: RequestOperationTypeProto
UNKNOWN_OPERATION: RequestOperationTypeProto
VALIDATE: RequestOperationTypeProto

class RequestOperationTypeProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
