# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/models/position/position_filter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.position import position_util_pb2 as fintekkers_dot_models_dot_position_dot_position__util__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0fintekkers/models/position/position_filter.proto\x12\x1a\x66intekkers.models.position\x1a.fintekkers/models/position/position_util.proto\"x\n\x13PositionFilterProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12:\n\x07\x66ilters\x18\x15 \x03(\x0b\x32).fintekkers.models.position.FieldMapEntryB\x18\x42\x14PositionFilterProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.position.position_filter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\024PositionFilterProtosP\001'
  _POSITIONFILTERPROTO._serialized_start=128
  _POSITIONFILTERPROTO._serialized_end=248
# @@protoc_insertion_point(module_scope)
